==> haskell-edit-distance-vector-1.0.0.4-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-edit-distance-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: edit-distance-vector
version: 1.0.0.4
id: edit-distance-vector-1.0.0.4-BEOrCqAjMhfIEDxZ8gqnif
key: edit-distance-vector-1.0.0.4-BEOrCqAjMhfIEDxZ8gqnif
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/edit-distance-vector
synopsis: Calculate edit distances and edit scripts between vectors.
description:
    An implementation of the Wagner–Fischer dynamic programming algorithm to
    find the optimal edit script and cost between two sequences.
    .
    The implementation in this package is specialised to sequences represented
    with "Data.Vector" but is otherwise agnostic to:
    .
    * The type of values in the vectors;
    .
    * The type representing edit operations; and
    .
    * The type representing the cost of operations.
    .
category: Data, Data Structures, Algorithms
abi: 272c66028354f8f8c320fd20ce02afe6
exposed: True
exposed-modules:
    Data.Vector.Distance
import-dirs: /usr/lib/ghc-8.6.4/site-local/edit-distance-vector-1.0.0.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/edit-distance-vector-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/edit-distance-vector-1.0.0.4
hs-libraries: HSedit-distance-vector-1.0.0.4-BEOrCqAjMhfIEDxZ8gqnif
depends:
    base-4.12.0.0 vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-edit-distance-vector/html/edit-distance-vector.haddock
haddock-html: /usr/share/doc/haskell-edit-distance-vector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edit-distance-vector-1.0.0.4-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-edit-distance-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: edit-distance-vector
version: 1.0.0.4
id: edit-distance-vector-1.0.0.4-1e8xrThEhwIGVL0oXkhvIf
key: edit-distance-vector-1.0.0.4-1e8xrThEhwIGVL0oXkhvIf
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/edit-distance-vector
synopsis: Calculate edit distances and edit scripts between vectors.
description:
    An implementation of the Wagner–Fischer dynamic programming algorithm to
    find the optimal edit script and cost between two sequences.
    .
    The implementation in this package is specialised to sequences represented
    with "Data.Vector" but is otherwise agnostic to:
    .
    * The type of values in the vectors;
    .
    * The type representing edit operations; and
    .
    * The type representing the cost of operations.
    .
category: Data, Data Structures, Algorithms
abi: b1b663a581ba8a1168c90e5ce7ec3d27
exposed: True
exposed-modules:
    Data.Vector.Distance
import-dirs: /usr/lib/ghc-8.6.5/site-local/edit-distance-vector-1.0.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/edit-distance-vector-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/edit-distance-vector-1.0.0.4
hs-libraries: HSedit-distance-vector-1.0.0.4-1e8xrThEhwIGVL0oXkhvIf
depends:
    base-4.12.0.0 vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-edit-distance-vector/html/edit-distance-vector.haddock
haddock-html: /usr/share/doc/haskell-edit-distance-vector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
